@@ -6,7 +6,7 @@ use warnings;
 
 use base 'Test::Builder::Module';
 
-our $VERSION = '0.46';
+our $VERSION = '0.47';
 our $AUTHORITY = 'cpan:JJNAPIORK';
 
 use Config::Any;
@@ -1444,7 +1444,7 @@ L<DBIx::Class>, L<DBIx::Class::Schema::PopulateMore>, L<DBIx::Class::Fixtures>
     abraxxa
     oalders
     felliott
-    VadimPushtaev
+    Vadim Pushtaev C<< <pushtaev@cpan.org> >>
 
 =head1 COPYRIGHT & LICENSE
 
